@@ -4,36 +4,6 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-library(admiral)
-
-link <- function(text, url) {
-  return(
-    paste0(
-      "[", text, "]",
-      "(", url, ")"
-    )
-  )
-}
-dyn_link <- function(text,
-                     base_url,
-                     relative_url = "",
-                     # Change to TRUE when admiral adopts multiversion docs
-                     is_multiversion = FALSE,
-                     multiversion_default_ref = "main") {
-  url <- paste(base_url, relative_url, sep = "/")
-  if (is_multiversion) {
-    url <- paste(
-      base_url,
-      Sys.getenv("BRANCH_NAME", multiversion_default_ref),
-      relative_url,
-      sep = "/"
-    )
-  }
-  return(link(text, url))
-}
-# Other variables
-admiral_homepage <- "https://pharmaverse.github.io/admiral/cran-release"
-
 library(admiraldev)
 
 ## ----message=FALSE------------------------------------------------------------
@@ -41,13 +11,13 @@ library(admiral)
 library(admiralonco)
 library(dplyr)
 library(pharmaversesdtm)
+library(pharmaverseadam)
 library(lubridate)
 library(stringr)
-data("admiral_adsl")
+data("adsl")
 data("rs_onco_recist")
 data("tu_onco_recist")
 
-adsl <- admiral_adsl
 rs <- rs_onco_recist
 tu <- tu_onco_recist
 
@@ -87,7 +57,7 @@ adrs <- adrs %>%
     PARAM = "Overall Response by Investigator",
     PARCAT1 = "Tumor Response",
     PARCAT2 = "Investigator",
-    PARCAT3 = "Recist 1.1"
+    PARCAT3 = "RECIST 1.1"
   )
 
 ## ---- echo=FALSE--------------------------------------------------------------
@@ -126,12 +96,24 @@ dataset_vignette(
 )
 
 ## -----------------------------------------------------------------------------
+worst_resp <- function(arg) {
+  case_when(
+    arg == "NE" ~ 1,
+    arg == "CR" ~ 2,
+    arg == "PR" ~ 3,
+    arg == "SD" ~ 4,
+    arg == "NON-CR/NON-PD" ~ 5,
+    arg == "PD" ~ 6,
+    TRUE ~ 0
+  )
+}
+
 adrs <- adrs %>%
   restrict_derivation(
     derivation = derive_var_extreme_flag,
     args = params(
       by_vars = exprs(STUDYID, USUBJID, ADT),
-      order = exprs(AVAL, RSSEQ),
+      order = exprs(worst_resp(AVALC), RSSEQ),
       new_var = ANL01FL,
       mode = "last"
     ),
@@ -193,7 +175,7 @@ crsp_y_cr <- event_joined(
   join_vars = exprs(AVALC, ADT),
   join_type = "after",
   order = exprs(ADT),
-  first_cond = AVALC.join == "CR" &
+  first_cond_upper = AVALC.join == "CR" &
     ADT.join >= ADT + days(confirmation_period),
   condition = AVALC == "CR" &
     all(AVALC.join %in% c("CR", "NE")) &
@@ -211,7 +193,7 @@ crsp_y_pr <- event_joined(
   join_vars = exprs(AVALC, ADT),
   join_type = "after",
   order = exprs(ADT),
-  first_cond = AVALC.join %in% c("CR", "PR") &
+  first_cond_upper = AVALC.join %in% c("CR", "PR") &
     ADT.join >= ADT + days(confirmation_period),
   condition = AVALC == "PR" &
     all(AVALC.join %in% c("CR", "PR", "NE")) &
@@ -237,7 +219,7 @@ cbor_cr <- event_joined(
   dataset_name = "ovr",
   join_vars = exprs(AVALC, ADT),
   join_type = "after",
-  first_cond = AVALC.join == "CR" &
+  first_cond_upper = AVALC.join == "CR" &
     ADT.join >= ADT + confirmation_period,
   condition = AVALC == "CR" &
     all(AVALC.join %in% c("CR", "NE")) &
@@ -255,7 +237,7 @@ cbor_pr <- event_joined(
   dataset_name = "ovr",
   join_vars = exprs(AVALC, ADT),
   join_type = "after",
-  first_cond = AVALC.join %in% c("CR", "PR") &
+  first_cond_upper = AVALC.join %in% c("CR", "PR") &
     ADT.join >= ADT + confirmation_period,
   condition = AVALC == "PR" &
     all(AVALC.join %in% c("CR", "PR", "NE")) &
@@ -300,12 +282,13 @@ adrs <- adrs %>%
     order = exprs(ADT, RSSEQ),
     mode = "first",
     exist_flag = AVALC,
+    false_value = "N",
     set_values_to = exprs(
       PARAMCD = "PD",
       PARAM = "Disease Progression by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
@@ -325,7 +308,8 @@ rsp_y
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(ADT),
+    order = exprs(event_nr, ADT),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     events = list(rsp_y, no_data_n),
     source_datasets = list(
@@ -337,7 +321,7 @@ adrs <- adrs %>%
       PARAM = "Response by Investigator (confirmation not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
@@ -357,24 +341,23 @@ cb_y
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(desc(AVALC), ADT),
+    order = exprs(desc(AVALC), ADT, event_nr),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     events = list(rsp_y, cb_y, no_data_n),
     source_datasets = list(
       ovr = ovr,
       adsl = adsl
     ),
-    ignore_event_order = TRUE,
     set_values_to = exprs(
       PARAMCD = "CB",
       PARAM = "Clinical Benefit by Investigator (confirmation for response not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
-    ),
-    check_type = "none"
+    )
   )
 
 ## ---- echo=FALSE--------------------------------------------------------------
@@ -388,7 +371,8 @@ dataset_vignette(
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(ADT),
+    order = exprs(event_nr, ADT),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     source_datasets = list(
       ovr = ovr,
@@ -400,7 +384,7 @@ adrs <- adrs %>%
       PARAM = "Best Overall Response by Investigator (confirmation not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = aval_resp(AVALC),
       ANL01FL = "Y"
     )
@@ -435,12 +419,13 @@ adrs <- adrs %>%
     by_vars = exprs(STUDYID, USUBJID),
     filter_add = PARAMCD == "BOR" & AVALC %in% c("CR", "PR"),
     exist_flag = AVALC,
+    false_value = "N",
     set_values_to = exprs(
       PARAMCD = "BCP",
       PARAM = "Best Overall Response of CR/PR by Investigator (confirmation not required)",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
@@ -469,20 +454,20 @@ cbor_pr
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(desc(AVALC), ADT),
+    order = exprs(desc(AVALC), ADT, event_nr),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     source_datasets = list(
       ovr = ovr,
       adsl = adsl
     ),
     events = list(crsp_y_cr, crsp_y_pr, no_data_n),
-    ignore_event_order = TRUE,
     set_values_to = exprs(
       PARAMCD = "CRSP",
       PARAM = "Confirmed Response by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
@@ -491,30 +476,30 @@ adrs <- adrs %>%
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(desc(AVALC), ADT),
+    order = exprs(desc(AVALC), ADT, event_nr),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     events = list(crsp_y_cr, crsp_y_pr, cb_y, no_data_n),
     source_datasets = list(
       ovr = ovr,
       adsl = adsl
     ),
-    ignore_event_order = TRUE,
     set_values_to = exprs(
       PARAMCD = "CCB",
       PARAM = "Confirmed Clinical Benefit by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
-    ),
-    check_type = "none"
+    )
   )
 
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(ADT),
+    order = exprs(event_nr, ADT),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     events = list(cbor_cr, cbor_pr, bor_sd, bor_non_crpd, bor_pd, bor_ne, no_data_missing),
     source_datasets = list(
@@ -526,7 +511,7 @@ adrs <- adrs %>%
       PARAM = "Best Confirmed Overall Response by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = aval_resp(AVALC),
       ANL01FL = "Y"
     )
@@ -537,12 +522,13 @@ adrs <- adrs %>%
     by_vars = exprs(STUDYID, USUBJID),
     filter_add = PARAMCD == "CBOR" & AVALC %in% c("CR", "PR"),
     exist_flag = AVALC,
+    false_value = "N",
     set_values_to = exprs(
       PARAMCD = "CBCP",
       PARAM = "Best Confirmed Overall Response of CR/PR by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
@@ -569,24 +555,23 @@ cb_y_pd <- event(
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(desc(AVALC), ADT),
+    order = exprs(desc(AVALC), ADT, event_nr),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     events = list(crsp_y_cr, crsp_y_pr, cb_y, cb_y_pd, no_data_n),
     source_datasets = list(
       ovr = ovr,
       adsl = adsl
     ),
-    ignore_event_order = TRUE,
     set_values_to = exprs(
       PARAMCD = "ACCB",
       PARAM = "Alternative Confirmed Clinical Benefit by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
-    ),
-    check_type = "none"
+    )
   )
 
 ## -----------------------------------------------------------------------------
@@ -603,7 +588,8 @@ bor_ned <- event(
 adrs <- adrs %>%
   derive_extreme_event(
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(ADT),
+    order = exprs(event_nr, ADT),
+    tmp_event_nr_var = event_nr,
     mode = "first",
     source_datasets = list(
       ovr = ovr,
@@ -614,11 +600,11 @@ adrs <- adrs %>%
       PARAMCD = "A1BOR",
       PARAM = paste(
         "Best Overall Response by Investigator (confirmation not required)",
-        "- Recist 1.1 adjusted for NED at Baseline"
+        "- RECIST 1.1 adjusted for NED at Baseline"
       ),
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1 adjusted for NED at Baseline",
+      PARCAT3 = "RECIST 1.1 adjusted for NED at Baseline",
       AVAL = aval_resp(AVALC),
       ANL01FL = "Y"
     )
@@ -634,7 +620,7 @@ adrs_bicr <- rs %>%
     PARAM = "Overall Response by BICR",
     PARCAT1 = "Tumor Response",
     PARCAT2 = "Blinded Independent Central Review",
-    PARCAT3 = "Recist 1.1"
+    PARCAT3 = "RECIST 1.1"
   )
 
 ## ---- echo=FALSE--------------------------------------------------------------
@@ -655,6 +641,7 @@ adrs <- adrs %>%
     by_vars = exprs(STUDYID, USUBJID),
     filter_add = !is.na(DTHDT),
     exist_flag = AVALC,
+    false_value = "N",
     set_values_to = exprs(
       PARAMCD = "DEATH",
       PARAM = "Death",
@@ -687,7 +674,7 @@ adrs <- adrs %>%
       PARAM = "Last Disease Assessment by Investigator",
       PARCAT1 = "Tumor Response",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       ANL01FL = "Y"
     )
   )
@@ -714,7 +701,7 @@ adrs <- adrs %>%
       PARAMCD = "MDIS",
       PARAM = "Measurable Disease at Baseline by Investigator",
       PARCAT2 = "Investigator",
-      PARCAT3 = "Recist 1.1",
+      PARCAT3 = "RECIST 1.1",
       AVAL = yn_to_numeric(AVALC),
       ANL01FL = "Y"
     )
