@@ -3,47 +3,19 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
-link <- function(text, url) {
-  return(
-    paste0(
-      "[", text, "]",
-      "(", url, ")"
-    )
-  )
-}
-dyn_link <- function(text,
-                     base_url,
-                     relative_url = "",
-                     # Change to TRUE when admiral adopts multiversion docs
-                     is_multiversion = FALSE,
-                     multiversion_default_ref = "main") {
-  url <- paste(base_url, relative_url, sep = "/")
-  if (is_multiversion) {
-    url <- paste(
-      base_url,
-      Sys.getenv("BRANCH_NAME", multiversion_default_ref),
-      relative_url,
-      sep = "/"
-    )
-  }
-  return(link(text, url))
-}
-# Other variables
-admiral_homepage <- "https://pharmaverse.github.io/admiral/cran-release"
-
 library(admiraldev)
 
 ## ---- warning=FALSE, message=FALSE--------------------------------------------
 library(admiral)
 library(admiralonco)
+library(pharmaverseadam)
 library(dplyr)
 library(lubridate)
 
 ## -----------------------------------------------------------------------------
-data("admiral_adsl")
-data("admiral_adrs")
-adsl <- admiral_adsl
-adrs <- admiral_adrs
+data("adsl")
+data("adrs_onco")
+adrs <- adrs_onco
 
 ## ----echo=FALSE---------------------------------------------------------------
 knitr::kable(list_tte_source_objects(package = "admiralonco"))
